==> smart-article-core-20.2.1-sources.jar: net/guerlab/smart/article/core/domain/ArticleDTO.java <==
package net.guerlab.smart.article.core.domain;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import net.guerlab.smart.article.core.eneity.Attachments;
import net.guerlab.smart.article.core.enums.AuditStatus;
import net.guerlab.smart.article.core.enums.PublishType;
import net.guerlab.smart.platform.commons.domain.MultiId;
import net.guerlab.smart.platform.commons.entity.BaseOrderEntity;

import java.time.LocalDateTime;
import java.util.Collection;

/**
 * 文章
 *
 * @author guer
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel("文章")
public class ArticleDTO extends BaseOrderEntity<ArticleDTO> {

    /**
     * 文章ID
     */
    @ApiModelProperty("文章ID")
    private Long articleId;

    /**
     * 唯一key
     */
    @ApiModelProperty("唯一key")
    private String uniqueKey;

    /**
     * 文章分类ID
     */
    @ApiModelProperty("文章分类ID")
    private Long articleCategoryId;

    /**
     * 文章分类名称
     */
    @ApiModelProperty("文章分类名称")
    private String articleCategoryName;

    /**
     * 文章分类类型
     */
    @ApiModelProperty("文章分类类型")
    private String articleCategoryType;

    /**
     * 次要文章分类ID列表
     */
    @ApiModelProperty("次要文章分类ID列表")
    private MultiId secondaryArticleCategoryIds;

    /**
     * 文章分类ID列表
     */
    @ApiModelProperty("文章分类ID列表")
    private MultiId articleCategoryIds;

    /**
     * 标题
     */
    @ApiModelProperty("标题")
    private String title;

    /**
     * 封面URL
     */
    @ApiModelProperty("封面URL")
    private String coverUrl;

    /**
     * 是否有封面
     */
    @ApiModelProperty("是否有封面")
    private Boolean hasCoverUrl;

    /**
     * 作者
     */
    @ApiModelProperty("作者")
    private String author;

    /**
     * 发布时间
     */
    @ApiModelProperty("发布时间")
    private LocalDateTime releaseTime;

    /**
     * 简介
     */
    @ApiModelProperty("简介")
    private String synopsis;

    /**
     * 内容
     */
    @ApiModelProperty("内容")
    private String content;

    /**
     * 已发布标志
     */
    @ApiModelProperty("已发布标志")
    private Boolean published;

    /**
     * 原文链接
     */
    @ApiModelProperty("原文链接")
    private String originalLink;

    /**
     * 总是跳转标志
     */
    @ApiModelProperty("总是跳转标志")
    private Boolean alwaysRedirect;

    /**
     * 发布方式
     */
    @ApiModelProperty("发布方式")
    private PublishType publishType;

    /**
     * 计划发布时间
     */
    @ApiModelProperty("计划发布时间")
    private LocalDateTime planPublishTime;

    /**
     * 实际发布时间
     */
    @ApiModelProperty("实际发布时间")
    private LocalDateTime publishTime;

    /**
     * 新建时间
     */
    @ApiModelProperty("新建时间")
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    @ApiModelProperty("更新时间")
    private LocalDateTime updateTime;

    /**
     * 附件列表
     */
    @ApiModelProperty("附件列表")
    private Attachments attachments;

    /**
     * 包含附件标志
     */
    @ApiModelProperty("包含附件标志")
    private Boolean hasAttachment;

    /**
     * 审核状态
     */
    @ApiModelProperty("审核状态")
    private AuditStatus auditStatus;

    /**
     * 阅读量
     */
    @ApiModelProperty("阅读量")
    private Long viewNumber;

    /**
     * 文章分类列表
     */
    @ApiModelProperty("文章分类列表")
    private Collection<ArticleCategoryDTO> categories;
}

==> smart-article-core-20.2.2-sources.jar: net/guerlab/smart/article/core/domain/ArticleDTO.java <==
package net.guerlab.smart.article.core.domain;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import net.guerlab.smart.article.core.eneity.Attachments;
import net.guerlab.smart.article.core.enums.AuditStatus;
import net.guerlab.smart.article.core.enums.PublishType;
import net.guerlab.smart.platform.commons.domain.MultiId;
import net.guerlab.smart.platform.commons.entity.BaseOrderEntity;

import java.time.LocalDateTime;
import java.util.Collection;

/**
 * 文章
 *
 * @author guer
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel("文章")
public class ArticleDTO extends BaseOrderEntity<ArticleDTO> {

    /**
     * 文章ID
     */
    @ApiModelProperty("文章ID")
    private Long articleId;

    /**
     * 唯一key
     */
    @ApiModelProperty("唯一key")
    private String uniqueKey;

    /**
     * 文章分类ID
     */
    @ApiModelProperty("文章分类ID")
    private Long articleCategoryId;

    /**
     * 文章分类名称
     */
    @ApiModelProperty("文章分类名称")
    private String articleCategoryName;

    /**
     * 文章分类类型
     */
    @ApiModelProperty("文章分类类型")
    private String articleCategoryType;

    /**
     * 次要文章分类ID列表
     */
    @ApiModelProperty("次要文章分类ID列表")
    private MultiId secondaryArticleCategoryIds;

    /**
     * 文章分类ID列表
     */
    @ApiModelProperty("文章分类ID列表")
    private MultiId articleCategoryIds;

    /**
     * 标题
     */
    @ApiModelProperty("标题")
    private String title;

    /**
     * seo-关键词
     */
    @ApiModelProperty("seo-关键词")
    private String keywords;

    /**
     * seo-页面描述
     */
    @ApiModelProperty("seo-页面描述")
    private String description;

    /**
     * 封面URL
     */
    @ApiModelProperty("封面URL")
    private String coverUrl;

    /**
     * 是否有封面
     */
    @ApiModelProperty("是否有封面")
    private Boolean hasCoverUrl;

    /**
     * 作者
     */
    @ApiModelProperty("作者")
    private String author;

    /**
     * 发布时间
     */
    @ApiModelProperty("发布时间")
    private LocalDateTime releaseTime;

    /**
     * 简介
     */
    @ApiModelProperty("简介")
    private String synopsis;

    /**
     * 内容
     */
    @ApiModelProperty("内容")
    private String content;

    /**
     * 已发布标志
     */
    @ApiModelProperty("已发布标志")
    private Boolean published;

    /**
     * 原文链接
     */
    @ApiModelProperty("原文链接")
    private String originalLink;

    /**
     * 总是跳转标志
     */
    @ApiModelProperty("总是跳转标志")
    private Boolean alwaysRedirect;

    /**
     * 发布方式
     */
    @ApiModelProperty("发布方式")
    private PublishType publishType;

    /**
     * 计划发布时间
     */
    @ApiModelProperty("计划发布时间")
    private LocalDateTime planPublishTime;

    /**
     * 实际发布时间
     */
    @ApiModelProperty("实际发布时间")
    private LocalDateTime publishTime;

    /**
     * 新建时间
     */
    @ApiModelProperty("新建时间")
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    @ApiModelProperty("更新时间")
    private LocalDateTime updateTime;

    /**
     * 附件列表
     */
    @ApiModelProperty("附件列表")
    private Attachments attachments;

    /**
     * 包含附件标志
     */
    @ApiModelProperty("包含附件标志")
    private Boolean hasAttachment;

    /**
     * 审核状态
     */
    @ApiModelProperty("审核状态")
    private AuditStatus auditStatus;

    /**
     * 阅读量
     */
    @ApiModelProperty("阅读量")
    private Long viewNumber;

    /**
     * 文章分类列表
     */
    @ApiModelProperty("文章分类列表")
    private Collection<ArticleCategoryDTO> categories;
}
